@@ -2,8 +2,8 @@
  * Copyright (c) Eric D. Friedman 1998. All Rights Reserved.
  * Copyright (c) Paul Kinnucan 1998. All Rights Reserved.
  *
- * $Revision: 1.4 $ 
- * $Date: 2001/10/14 22:20:28 $ 
+ * $Revision: 1.7 $ 
+ * $Date: 2003/01/18 05:48:41 $ 
  *
  * InterfaceFactory is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -36,7 +36,7 @@ import java.util.Enumeration;
  * multiple interfaces when invoked from the command line.
  *
  * @author Eric D. Friedman and Paul Kinnucan
- * @version $Revision: 1.4 $
+ * @version $Revision: 1.7 $
  */
 
 public class InterfaceFactory extends MethodFactory
@@ -44,7 +44,7 @@ public class InterfaceFactory extends MethodFactory
 
   /** A table w/ declaring classes as keys and vectors of method
    * signatures as values */
-  private Hashtable interfaces = new Hashtable();
+  protected Hashtable interfaces = new Hashtable();
 
   /** The interface factory. */
   static InterfaceFactory interfaceFactory;
@@ -146,25 +146,23 @@ public class InterfaceFactory extends MethodFactory
 
 
   /**
-   * Makes an implementation of an interface. This method delegates the creation
-   * of the implementation to makeInterfaceInternal.
+   * Makes an expression for generating the implementation of an
+   * interface. This method delegates the creation of the
+   * implementation to makeInterfaceExpressionInternal.
    *
    * @param name Name of interface to be implemented.
-   * @param javadoc If <code>true</code> generate skeletal Javadoc for the implementation.
-   * @param truncate If <code>true</code>, truncate package specifier when generating code.
-   * @param newline If <code>true</code>, insert a newline after opening brace.
-   * 
+   * @param truncate If <code>true</code>, truncate package specifier
+   * when generating code.
    */
-  public static void makeInterface(String name, 
-			           boolean javadoc,
-				   boolean truncate,
-				   boolean newline) {
+
+  public static void makeInterfaceExpression
+      (String name, boolean truncate) {
 
     if (interfaceFactory == null)
       interfaceFactory = new InterfaceFactory();
 
     interfaceFactory.flush();
-    interfaceFactory.makeInterfaceInternal(name, javadoc, truncate, newline);
+    interfaceFactory.makeInterfaceExpressionInternal(name, truncate);
 
   }
 
@@ -172,15 +170,11 @@ public class InterfaceFactory extends MethodFactory
    * Makes an implementation of an interface.
    *
    * @param name Name of interface to be implemented.
-   * @param javadoc If <code>true</code> generate skeletal Javadoc for the implementation.
-   * @param truncate If <code>true</code>, truncate package specifier when generating code.
-   * @param newline If <code>true</code>, insert a newline after opening brace.
-   * 
+   * @param truncate If <code>true</code>, truncate package specifier
+   * when generating code.
    */
-  private void makeInterfaceInternal(String name,
-				     boolean javadoc,
-				     boolean truncate,
-				     boolean newline) {
+  protected void makeInterfaceExpressionInternal 
+      (String name, boolean truncate) {
     try {
       process(name, truncate);
     }
@@ -198,49 +192,39 @@ public class InterfaceFactory extends MethodFactory
       return;
     }
 
-    dump(new PrintWriter( System.out, true),
-	 javadoc,
-	 truncate,
-	 newline );
+    dumpExpression(new PrintWriter( System.out, true), truncate);
   }
 
 
   public static void getImportedClasses() {
-    String res = "(list ";
-    Enumeration i = interfaceFactory.imports.keys();
-    while (i.hasMoreElements()) {
-      Class c = (Class) i.nextElement();
-      res += "\"" + c.getName() + "\" ";
-    }
-    res += ")";
-    println(res);
+    println(interfaceFactory.getImportsAsList());
   }
 
 
-  public void dump(PrintWriter out,
-                          boolean javadoc,
-                          boolean truncate,
-                          boolean newline)
+  public void dumpExpression(PrintWriter out, boolean truncate)
   {
-    StringBuffer buf = new StringBuffer("\"");
+    StringBuffer buf = new StringBuffer
+	("(jde-wiz-gen-implementation-methods (list ");
 
     Enumeration declaring_classes = interfaces.keys();
     while (declaring_classes.hasMoreElements())
     {
       String interf = (String)declaring_classes.nextElement();
       Vector v = (Vector)interfaces.get(interf);
-      buf.append("// implementation of ");
+      buf.append ("(quote ");
+      buf.append("\"Implementation of ");
       buf.append(interf);
-      buf.append(" interface\n");
+      buf.append("\")");
       Enumeration e = v.elements();
       while (e.hasMoreElements())
       {
         Signature sig = (Signature)e.nextElement();
-        String todo = "  // TODO: implement this " + interf + " method\n";
-        buf.append(getMethodSkeleton(sig, javadoc, newline, todo));
+	buf.append ("(quote ");
+        buf.append(getMethodSkeletonExpression(sig));
+	buf.append (")");
       } // end of while (e.hasMoreElements())
     }
-    buf.append("\"");
+    buf.append("))");
     println(buf.toString());
   }
 } // SignatureFactory
@@ -255,8 +239,17 @@ class NotAnInterfaceException extends Exception
 
 /*
  * $Log: InterfaceFactory.java,v $
- * Revision 1.4  2001/10/14 22:20:28  andyp
- * Sync to 2.2.8
+ * Revision 1.7  2003/01/18 05:48:41  andyp
+ * sync to jde 2.3.2
+ *
+ * Revision 1.9  2002/05/14 06:38:44  paulk
+ * Enhances code generation wizards for implementing interfaces, abstract
+ * classes, etc., to use customizable templates to generate skeleton methods
+ * instead of hard-wired skeletons. Thanks to "Dr. Michael Lipp" <lipp@danet.de>
+ * for proposing and implementing this improvement.
+ *
+ * Revision 1.8  2001/10/21 14:06:41  paulk
+ * Changed some methods from private to protected to permit overriding by descendent classes.
  *
  * Revision 1.7  2001/08/04 03:24:10  paulk
  * DefaultNameFactory.java
